@@ -8,4 +8,4 @@ def vec3_from_np_array(np_array: np.ndarray) -> ffi.CData:
 
 
 def np_array_from_vec3(vec3: ffi.CData) -> np.ndarray:
-    return np.frombuffer(ffi.buffer(vec3.v, 3 * 8), dtype=np.float64)
+    return np.copy(np.frombuffer(ffi.buffer(vec3.v, 3 * 8), dtype=np.float64))
